The vesalius_assay class is the functional unit of vesalius. Each assay is stored within this class and it contains all the required information to run analysis on your assay of choice. In this object, you can find spatial tiles, image embeddings, spatial territories, differentially expressed genes (DEG), count matrices (raw and normalised), microscopy images (if present) and a functional log that lets you see what had been run on this object.
Slots
assaycharacter assay name
tilesdata.frame containing spatial coordinates and pixels tiles once they have been computed
embeddingslist containing latent space embeddings in the form of data.frames.
activematrix containing active embedding data
territoriesdata.frame containing spatial color segments, spatial territories, or layers.
DEGlist of data.frame for each differentially gene expression trial
countslist that containing count matrices. Raw and normalised will be stored here and named by the normalisation method used.
metalist containing metadata associated with the assay
costlist containing cost matrices used for mapping assays
mapdata.frame containing mapping results between assays
imagelist containing associated microscopy images (NOT implemented)
loglist containing analysis history of the object.